pub struct BlockStat { /* private fields */ }Expand description
Gathers statistics for each block obtained from the Ann flathnsw representation for comparison with those obtained of the
original graph representation.
We collect mean distances inside a block and mean distance for edge crossing a block boundary.
We also collect transition probabilities between blocks.
The data collected depend on parameter ef_construction used in Hnsw creation.
The higher ef_construction, the more representative are collected data, at the expense of cpu.
ef = 48 or 64 seem a good compromise, a rule of thumb is ef should be higher than mean graph degree.
Implementations
Sourceimpl BlockStat
impl BlockStat
pub fn new( blocnum: usize, block_degree: u32, mean_dist: f64, mean_dist_in: f32, mean_dist_out: f32, min_dist_in_block: f64, transition_proba: Vec<f32>, kl_divergence: f32, ) -> Self
Sourcepub fn get_blocnum(&self) -> usize
pub fn get_blocnum(&self) -> usize
returns num of block for hich the structure maintains statistics
Sourcepub fn get_block_degree(&self) -> u32
pub fn get_block_degree(&self) -> u32
returns total number of edge involving a node in this block
Sourcepub fn get_mean(&self) -> f64
pub fn get_mean(&self) -> f64
returns distance among all neighbours reference in flat neighborhood
Sourcepub fn get_mean_dist_in(&self) -> f32
pub fn get_mean_dist_in(&self) -> f32
returns mean of distance between embedded pairs of point inside block
Sourcepub fn get_mean_dist_out(&self) -> f32
pub fn get_mean_dist_out(&self) -> f32
returns mean of distance between embedded pairs of point one inside , the other outside block
Sourcepub fn get_min_dist_in_block(&self) -> f64
pub fn get_min_dist_in_block(&self) -> f64
minimal dist among neighbour in same block as point
Sourcepub fn get_fraction_out(&self) -> f32
pub fn get_fraction_out(&self) -> f32
returns fraction of transition going out of block (i.e going into block of highrer index)
Sourcepub fn get_kl_divergence(&self) -> f32
pub fn get_kl_divergence(&self) -> f32
for a given block, edges going out of block have an block arrival distribution. This function return kl_divergene the transition observed in the original graph and the embedded graph.